@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the test suite of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -50,8 +42,8 @@
 #include <limits.h>
 
 #include <qnumeric.h>
-#include <qgeopositioninfosource.h>
-#include <qgeopositioninfo.h>
+#include <QtPositioning/qgeopositioninfosource.h>
+#include <QtPositioning/qgeopositioninfo.h>
 
 #include "testqgeopositioninfosource_p.h"
 #include "../utils/qlocationtestutils_p.h"
@@ -113,7 +105,7 @@ class DefaultSourceTest : public TestQGeoPositionInfoSource
     Q_OBJECT
 protected:
     QGeoPositionInfoSource *createTestSource() {
-        return QGeoPositionInfoSource::createDefaultSource(0);
+        return QGeoPositionInfoSource::createSource(QStringLiteral("test.source"), 0);
     }
 };
 
@@ -125,8 +117,13 @@ TestQGeoPositionInfoSource::TestQGeoPositionInfoSource(QObject *parent)
     /*
      * Set custom path since CI doesn't install test plugins
      */
+#ifdef Q_OS_WIN
+    QCoreApplication::addLibraryPath(QCoreApplication::applicationDirPath() +
+                                     QStringLiteral("/../../../../plugins"));
+#else
     QCoreApplication::addLibraryPath(QCoreApplication::applicationDirPath()
                                      + QStringLiteral("/../../../plugins"));
+#endif
 }
 
 TestQGeoPositionInfoSource *TestQGeoPositionInfoSource::createDefaultSourceTest()
@@ -332,7 +329,7 @@ void TestQGeoPositionInfoSource::lastKnownPosition()
 
     m_source->setPreferredPositioningMethods(positioningMethod);
 
-    QSignalSpy spy(m_source, SIGNAL(positionUpdated(const QGeoPositionInfo&)));
+    QSignalSpy spy(m_source, SIGNAL(positionUpdated(QGeoPositionInfo)));
     QSignalSpy timeout(m_source, SIGNAL(updateTimeout()));
     int time_out = 7000;
     m_source->setUpdateInterval(time_out);
@@ -346,7 +343,7 @@ void TestQGeoPositionInfoSource::lastKnownPosition()
     //simulated CI tests will quickly return -> real GPS tests take 2 minutes for satellite systems
     //use a 5 min timeout
     timer.setInterval(300000);
-    connect(m_source, SIGNAL(positionUpdated(const QGeoPositionInfo&)),
+    connect(m_source, SIGNAL(positionUpdated(QGeoPositionInfo)),
             &loop, SLOT(quit()));
     connect(&timer, SIGNAL(timeout()), &loop, SLOT(quit()));
     timer.start();
@@ -429,7 +426,7 @@ void TestQGeoPositionInfoSource::minimumUpdateInterval()
 void TestQGeoPositionInfoSource::startUpdates_testIntervals()
 {
     CHECK_SOURCE_VALID;
-    QSignalSpy spy(m_source, SIGNAL(positionUpdated(const QGeoPositionInfo&)));
+    QSignalSpy spy(m_source, SIGNAL(positionUpdated(QGeoPositionInfo)));
     QSignalSpy timeout(m_source, SIGNAL(updateTimeout()));
     m_source->setUpdateInterval(7000);
     int interval = m_source->updateInterval();
@@ -457,7 +454,7 @@ void TestQGeoPositionInfoSource::startUpdates_testIntervalChangesWhileRunning()
 
     CHECK_SOURCE_VALID;
 
-    QSignalSpy spy(m_source, SIGNAL(positionUpdated(const QGeoPositionInfo&)));
+    QSignalSpy spy(m_source, SIGNAL(positionUpdated(QGeoPositionInfo)));
     QSignalSpy timeout(m_source, SIGNAL(updateTimeout()));
     m_source->setUpdateInterval(0);
     m_source->startUpdates();
@@ -505,7 +502,7 @@ void TestQGeoPositionInfoSource::startUpdates_testDefaultInterval()
 {
     CHECK_SOURCE_VALID;
 
-    QSignalSpy spy(m_source, SIGNAL(positionUpdated(const QGeoPositionInfo&)));
+    QSignalSpy spy(m_source, SIGNAL(positionUpdated(QGeoPositionInfo)));
     QSignalSpy timeout(m_source, SIGNAL(updateTimeout()));
     m_source->startUpdates();
     for (int i = 0; i < 3; i++) {
@@ -521,7 +518,7 @@ void TestQGeoPositionInfoSource::startUpdates_testZeroInterval()
 {
     CHECK_SOURCE_VALID;
 
-    QSignalSpy spy(m_source, SIGNAL(positionUpdated(const QGeoPositionInfo&)));
+    QSignalSpy spy(m_source, SIGNAL(positionUpdated(QGeoPositionInfo)));
     QSignalSpy timeout(m_source, SIGNAL(updateTimeout()));
     m_source->setUpdateInterval(0);
     m_source->startUpdates();
@@ -536,7 +533,7 @@ void TestQGeoPositionInfoSource::startUpdates_moreThanOnce()
 {
     CHECK_SOURCE_VALID;
 
-    QSignalSpy spy(m_source, SIGNAL(positionUpdated(const QGeoPositionInfo&)));
+    QSignalSpy spy(m_source, SIGNAL(positionUpdated(QGeoPositionInfo)));
     QSignalSpy timeout(m_source, SIGNAL(updateTimeout()));
     m_source->setUpdateInterval(0);
     m_source->startUpdates();
@@ -555,7 +552,7 @@ void TestQGeoPositionInfoSource::stopUpdates()
 {
     CHECK_SOURCE_VALID;
 
-    QSignalSpy spy(m_source, SIGNAL(positionUpdated(const QGeoPositionInfo&)));
+    QSignalSpy spy(m_source, SIGNAL(positionUpdated(QGeoPositionInfo)));
     QSignalSpy timeout(m_source, SIGNAL(updateTimeout()));
     m_source->setUpdateInterval(7000);
     m_source->startUpdates();
@@ -601,7 +598,7 @@ void TestQGeoPositionInfoSource::requestUpdate_validTimeout()
 {
     CHECK_SOURCE_VALID;
 
-    QSignalSpy spyUpdate(m_source, SIGNAL(positionUpdated(const QGeoPositionInfo&)));
+    QSignalSpy spyUpdate(m_source, SIGNAL(positionUpdated(QGeoPositionInfo)));
     QSignalSpy spyTimeout(m_source, SIGNAL(updateTimeout()));
 
     m_source->requestUpdate(7000);
@@ -612,7 +609,7 @@ void TestQGeoPositionInfoSource::requestUpdate_validTimeout()
 void TestQGeoPositionInfoSource::requestUpdate_defaultTimeout()
 {
     CHECK_SOURCE_VALID;
-    QSignalSpy spyUpdate(m_source, SIGNAL(positionUpdated(const QGeoPositionInfo&)));
+    QSignalSpy spyUpdate(m_source, SIGNAL(positionUpdated(QGeoPositionInfo)));
     QSignalSpy spyTimeout(m_source, SIGNAL(updateTimeout()));
 
     m_source->requestUpdate(0);
@@ -637,7 +634,7 @@ void TestQGeoPositionInfoSource::requestUpdate_repeatedCalls()
 {
     CHECK_SOURCE_VALID;
 
-    QSignalSpy spyUpdate(m_source, SIGNAL(positionUpdated(const QGeoPositionInfo&)));
+    QSignalSpy spyUpdate(m_source, SIGNAL(positionUpdated(QGeoPositionInfo)));
     QSignalSpy spyTimeout(m_source, SIGNAL(updateTimeout()));
 
     m_source->requestUpdate(7000);
@@ -653,7 +650,7 @@ void TestQGeoPositionInfoSource::requestUpdate_overlappingCalls()
 {
     CHECK_SOURCE_VALID;
 
-    QSignalSpy spyUpdate(m_source, SIGNAL(positionUpdated(const QGeoPositionInfo&)));
+    QSignalSpy spyUpdate(m_source, SIGNAL(positionUpdated(QGeoPositionInfo)));
     QSignalSpy spyTimeout(m_source, SIGNAL(updateTimeout()));
 
     m_source->requestUpdate(7000);
@@ -667,7 +664,7 @@ void TestQGeoPositionInfoSource::requestUpdateAfterStartUpdates_ZeroInterval()
 {
     CHECK_SOURCE_VALID;
 
-    QSignalSpy spyUpdate(m_source, SIGNAL(positionUpdated(const QGeoPositionInfo&)));
+    QSignalSpy spyUpdate(m_source, SIGNAL(positionUpdated(QGeoPositionInfo)));
     QSignalSpy spyTimeout(m_source, SIGNAL(updateTimeout()));
 
     m_source->setUpdateInterval(0);
@@ -691,7 +688,7 @@ void TestQGeoPositionInfoSource::requestUpdateAfterStartUpdates_SmallInterval()
 {
     CHECK_SOURCE_VALID;
 
-    QSignalSpy spyUpdate(m_source, SIGNAL(positionUpdated(const QGeoPositionInfo&)));
+    QSignalSpy spyUpdate(m_source, SIGNAL(positionUpdated(QGeoPositionInfo)));
     QSignalSpy spyTimeout(m_source, SIGNAL(updateTimeout()));
 
     m_source->setUpdateInterval(10000);
@@ -714,7 +711,7 @@ void TestQGeoPositionInfoSource::requestUpdateBeforeStartUpdates_ZeroInterval()
 {
     CHECK_SOURCE_VALID;
 
-    QSignalSpy spyUpdate(m_source, SIGNAL(positionUpdated(const QGeoPositionInfo&)));
+    QSignalSpy spyUpdate(m_source, SIGNAL(positionUpdated(QGeoPositionInfo)));
     QSignalSpy spyTimeout(m_source, SIGNAL(updateTimeout()));
 
     m_source->requestUpdate(7000);
@@ -735,7 +732,7 @@ void TestQGeoPositionInfoSource::requestUpdateBeforeStartUpdates_ZeroInterval()
 void TestQGeoPositionInfoSource::requestUpdateBeforeStartUpdates_SmallInterval()
 {
     CHECK_SOURCE_VALID;
-    QSignalSpy spyUpdate(m_source, SIGNAL(positionUpdated(const QGeoPositionInfo&)));
+    QSignalSpy spyUpdate(m_source, SIGNAL(positionUpdated(QGeoPositionInfo)));
     QSignalSpy spyTimeout(m_source, SIGNAL(updateTimeout()));
 
     m_source->requestUpdate(7000);
@@ -770,11 +767,11 @@ void TestQGeoPositionInfoSource::removeSlotForPositionUpdated()
 {
     CHECK_SOURCE_VALID;
 
-    bool i = connect(m_source, SIGNAL(positionUpdated(const QGeoPositionInfo &)), this, SLOT(test_slot1()));
+    bool i = connect(m_source, SIGNAL(positionUpdated(QGeoPositionInfo)), this, SLOT(test_slot1()));
     QVERIFY(i == true);
-    i = connect(m_source, SIGNAL(positionUpdated(const QGeoPositionInfo &)), this, SLOT(test_slot2()));
+    i = connect(m_source, SIGNAL(positionUpdated(QGeoPositionInfo)), this, SLOT(test_slot2()));
     QVERIFY(i == true);
-    i = disconnect(m_source, SIGNAL(positionUpdated(const QGeoPositionInfo &)), this, SLOT(test_slot1()));
+    i = disconnect(m_source, SIGNAL(positionUpdated(QGeoPositionInfo)), this, SLOT(test_slot1()));
     QVERIFY(i == true);
 
     m_source->requestUpdate(7000);
